AppTextSize class

Typography constants for font sizes used throughout the app.

Constructors

AppTextSize()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

appBarTitle → const double
App bar title text size (18.0).
body1 → const double
Body1 text (14.0).
body2 → const double
Body2 text (12.0).
buttonText → const double
Default button text size (14.0).
caption → const double
Caption text (10.0).
chipText → const double
Chip label text size (12.0).
headline1 → const double
Headline1 text (64.0).
headline2 → const double
Headline2 text (48.0).
headline3 → const double
Headline3 text (36.0).
headline4 → const double
Headline4 text (32.0).
headline5 → const double
Headline5 text (24.0).
headline6 → const double
Headline6 text (20.0).
lg → const double
Large text size (16.0).
md → const double
Medium text size (14.0).
sm → const double
Small text size (12.0).
subtitle1 → const double
Subtitle1 text (18.0).
subtitle2 → const double
Subtitle2 text (16.0).
tabText → const double
Tab label text size (14.0).
xl → const double
Extra large text size (18.0).
xs → const double
Extra small text size (10.0).
xxl → const double
Double extra large text size (20.0).
xxxl → const double
Triple extra large text size (24.0).
xxxxl → const double
Quadruple extra large text size (32.0).