EmailUtilities class abstract

Provides a collection of static methods for handling emails.

Constructors

EmailUtilities()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isValidEmail(String email) bool
Validates an email string using a regular expression.
maskEmail(String email) String
Masks the username part of an email, keeping the first and last characters.