PasswordUtilities class abstract

Provides a collection of static methods for password-related utilities.

Constructors

PasswordUtilities()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

checkPasswordStrength(String password) PasswordStrength
Checks the strength of a password and returns a PasswordStrength value.