RandomUtilities class abstract
Provides a collection of static methods for generating random data.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateRandomNumber(
int min, int max) → int - Generates a random integer between a minimum and maximum value (inclusive).
-
generateRandomString(
int length, {bool includeNumbers = true, bool includeSymbols = false}) → String -
Generates a random string of a specified
length.